@@ -27,7 +27,8 @@ class Event_type_usersManager(AuditManager):
         if not isinstance(event_type, Event_types):
             raise Exception(f'event_type must be a Event_types')
 
-        settings.LOCKS.acquire('Event_type_usersManager.get_bot')
+        key = 'Event_type_usersManager.get_bot'
+        settings.LOCKS.acquire(key)
         bot, _ = User.objects.get_or_create(
             username=f'event_{event_type.code}_bot',
             defaults=dict(
@@ -38,7 +39,7 @@ class Event_type_usersManager(AuditManager):
                 editing=False
             )
         )
-        settings.LOCKS.release('Event_type_usersManager.get_bot')
+        settings.LOCKS.release(key)
         return bot
 
     @staticmethod
