@@ -31,6 +31,13 @@ def delAttr(o, name):
     else:
         return False
 
+def delAttr1(o, name):
+    if name in o:
+        del o[name]
+        return o
+    else:
+        return o
+
 
 def isEmptyDict(dictionary):
     for element in dictionary:
@@ -183,8 +190,9 @@ def cleanProgresses(id_progresses=None, exclude_processes=None):
 
 
 class NotImplement(Exception):
-    def __init__(self):
-        super().__init__('Нет рееализации !!!!!!')
+    def __init__(self, text=''):
+        super().__init__(f'{text} Нет реализации !!!!!!')
+
 
 class Stack:
 
@@ -200,7 +208,7 @@ class Stack:
         return self.stack[len(self.stack) - index]
 
     def clear(self):
-        self.stack= []
+        self.stack = []
 
     def pop(self):
         if len(self.stack) < 1:
@@ -299,3 +307,7 @@ class Wrapper:
     def __init__(self, **kwargs):
         for k, v in kwargs.items():
             setattr(self, k, v() if callable(v) else v)
+
+    @property
+    def dict(self):
+        return self.__dict__
