@@ -43,14 +43,14 @@ class TreeAuditModelQuerySet(AuditQuerySet):
             res = super().raw(sql_text)
         elif id != None:
             sql_text = f'''WITH RECURSIVE r AS (
-                                SELECT *, 1 AS level
+                                SELECT {fields}, 1 AS level
                                 FROM {db_name}
                                 WHERE {child_id if include_self else parent_id} IN %s
                                       {"and " + where_clause.replace("where", "") if where_clause else ""}  
     
                                 union all
     
-                                SELECT {db_name}.*, r.level + 1 AS level
+                                SELECT {db_name}.{fields}, r.level + 1 AS level
                                 FROM {db_name}
                                     JOIN r
                                 ON {db_name}.{parent_id} = r.{child_id})
@@ -130,7 +130,8 @@ class TreeAuditModelQuerySet(AuditQuerySet):
                               include_self=True,
                               where_clause='',
                               distinct='',
-                              sql_text=None
+                              sql_text=None,
+                              fields='*'
                               ) -> int:
         return len(self.get_descendants(
             id=id,
@@ -142,7 +143,8 @@ class TreeAuditModelQuerySet(AuditQuerySet):
             include_self=include_self,
             where_clause=where_clause,
             distinct=distinct,
-            sql_text=sql_text
+            sql_text=sql_text,
+            fields=fields
         ))
 
 
@@ -218,6 +220,7 @@ class TreeAuditModelManager(AuditManager):
                               where_clause='',
                               distinct='',
                               sql_text=None,
+                              fields='*'
                               ) -> int:
         return self.get_queryset().get_descendants_count(
             id=id,
@@ -229,7 +232,8 @@ class TreeAuditModelManager(AuditManager):
             include_self=include_self,
             distinct=distinct,
             where_clause=where_clause,
-            sql_text=sql_text
+            sql_text=sql_text,
+            fields=fields
         )
 
     def get_queryset(self):
