@@ -5,8 +5,12 @@ import traceback
 
 import websocket
 from django.conf import settings
+from django.core.serializers.json import DjangoJSONEncoder
 
 from isc_common import setAttr
+from isc_common.ws.progressStack import WebSocketExt
+
+logger = logging.getLogger(__name__)
 
 
 class WebSocket:
@@ -91,8 +95,8 @@ class WebSocket:
             key = 'WebSocket.send_message'
             settings.LOCKS.acquire(key)
             url = f'ws://{host}:{port}/ws/{channel}/'
-            ws = websocket.create_connection(url)
-            ws.send(json.dumps(message))
+            ws = websocket.create_connection(url, class_=WebSocketExt)
+            ws.send(json.dumps(message, cls=DjangoJSONEncoder))
             ws.close()
             settings.LOCKS.release(key)
         except Exception as ex:
@@ -109,6 +113,44 @@ class WebSocket:
             del exc_info
             settings.LOCKS.release(key)
 
+    @staticmethod
+    def full_refresh_grid(grid_id):
+        WebSocket.send_message(
+            host=settings.WS_HOST,
+            port=settings.WS_PORT,
+            channel=f'application',
+            message=dict(type=grid_id),
+            logger=logger
+        )
+
+    @staticmethod
+    def row_refresh_grid(grid_id, records):
+        if not isinstance(records, list):
+            if isinstance(records, dict):
+                records = [records]
+            else:
+                raise Exception(f'records must be list or dict')
+
+        WebSocket.send_message(
+            host=settings.WS_HOST,
+            port=settings.WS_PORT,
+            channel=f'application',
+            message=dict(type=grid_id, records=records),
+            logger=logger
+        )
+
+    @staticmethod
+    def refresh_progres(grid_id, pk_filed_name, pk_value, progress_field_name, progress_done):
+
+        record = dict()
+        setAttr(record, pk_filed_name, pk_value)
+        setAttr(record, progress_field_name, progress_done)
+
+        WebSocket.row_refresh_grid(
+            grid_id=grid_id,
+            records=[record]
+        )
+
     @staticmethod
     def send_warning_message(**kwrags):
         setAttr(kwrags, 'type', 'warn')
